@@ -12,7 +12,7 @@ require DynaLoader;
 
 @EXPORT = qw();
 
-@EXPORT_OK = qw( leap encode decode valid_date date_string check_date calc_days dates_difference day_of_week calc_new_date date_to_short date_to_string week_number first_in_week weeks_in_year decode_date day_short_tab day_name_tab month_short_tab month_name_tab );
+@EXPORT_OK = qw( leap encode decode valid_date date_string check_date calc_days dates_difference day_of_week calc_new_date date_to_short date_to_string week_number first_in_week weeks_in_year decode_date day_short_tab day_name_tab month_short_tab month_name_tab days_in_month );
 
 # "Version" is available but not exported!
 # Call with "Date::DateCalc::Version()"!
